@@ -7,15 +7,15 @@ from sqlalchemy.orm import sessionmaker
 SQLALCHEMY_BINDS = {
     'cargoline':'mysql://root:RHyndmanfpp3@127.0.0.1:3306/cargoline',
     'usermanagement': 'mysql://root:RHyndmanfpp3@localhost/cargocast_usermanagement',
-    'forecast': 'mysql://root:RHyndmanfpp3@localhost/consignment',
+    'consignment': 'mysql://root:RHyndmanfpp3@localhost/consignment',
     'company':  'mysql://root:RHyndmanfpp3@localhost/company'
 }
 
-
+# pool_size=20, max_overflow=0
 
 cargoline_engine = db.create_engine(SQLALCHEMY_BINDS["cargoline"])
 usermanagement_engine = db.create_engine(SQLALCHEMY_BINDS["usermanagement"])
-forecast_engine = db.create_engine(SQLALCHEMY_BINDS["forecast"])
+forecast_engine = db.create_engine(SQLALCHEMY_BINDS["consignment"],pool_size=20, max_overflow=0)
 company_engine = db.create_engine(SQLALCHEMY_BINDS["company"])
 
 meta = MetaData()
@@ -27,5 +27,11 @@ Base = declarative_base(metadata = meta)
 # twine upload --skip-existing dist/*
 # source C:/Users/p.dietrich/Documents/CargoCast/cc-forecast/cc.forecast/virtualenv/.venv/Scripts/activate
 # pip uninstall cc_db
-# pip install cc_db==1.79
+# pip install cc_db==1.82
+
+
+#***TEST***
+# import cc_db.consignment.observation as o
+# from sqlalchemy.inspection import inspect
+# obj = o.Observation(TimeIndexId = "D",ForecastUnitId = "SE_PIECE", PartnerId = '4144', Value = 1234)
 
